@@ -1,3 +1,4 @@
+import os
 import pathlib
 from typing import Union
 
@@ -6,5 +7,4 @@ def resolve_qt_path(path: Union[str, pathlib.Path]) -> str:
     """Convert a path to a string compatible with Qt's path-using methods."""
     if isinstance(path, str):
         path = pathlib.Path(path)
-    path = path.resolve()
-    return str(path)
+    return os.path.abspath(path)
