@@ -1,7 +1,6 @@
 from dataclasses import dataclass
 from typing import Optional
 
-from neoscore.core import neoscore
 from neoscore.core.units import Unit
 from neoscore.interface.font_interface import FontInterface
 from neoscore.interface.positioned_object_interface import PositionedObjectInterface
@@ -20,18 +19,9 @@ class RichTextInterface(PositionedObjectInterface):
 
     width: Optional[Unit] = None
 
-    scale: float = 1
-
-    rotation: float = 0
-    """Rotation angle in degrees"""
-
-    z_index: int = 0
-    """Z-index controlling draw order."""
-
     def render(self):
         """Render the line to the scene."""
-        qt_object = self._create_qt_object()
-        neoscore.app_interface.scene.addItem(qt_object)
+        self._register_qt_object(self._create_qt_object())
 
     def _create_qt_object(self) -> QRichTextItem:
         """Create and return this interface's underlying Qt object"""
@@ -41,10 +31,9 @@ class RichTextInterface(PositionedObjectInterface):
         qt_object.setPos(point_to_qt_point_f(self.pos))
         qt_object.setTextWidth(self.width.base_value if self.width is not None else -1)
         qt_object.setFont(self.font.qt_object)
+        qt_object.setTransformOriginPoint(point_to_qt_point_f(self.transform_origin))
         if self.scale != 1:
             qt_object.setScale(self.scale)
         if self.rotation != 0:
             qt_object.setRotation(self.rotation)
-        if self.z_index != 0:
-            qt_object.setZValue(self.z_index)
         return qt_object
